@@ -22,19 +22,27 @@ public:
 	int    *gtype;
 	int    *inc;
 	double  mdeg;
+	int 	preEdges;
+	double *weightMatrix;
 	std::vector<std::vector<int> > nodelist;
 	std::vector<int> typeIncluded;
+	double (Graph::*getTypeToTypeWeightp)(int*, int*);
+
 	Graph();
 	virtual ~Graph();
 
-	void Init(Pp *pp0, int *gtype0, double *par, double *prepR, int *doDists, double *preDists, int *toroidal, int *inc, int *dbg );
+	void Init(Pp *pp0, int *gtype0, double *par, double *prepR, int *doDists, double *preDists, int *toroidal, int *inc, double *, int *dbg );
 	void setNodelist(std::vector<std::vector<int> > *nodelist_new);
 	void setNodelist(SEXP);
 	void addNew(int , int);
+	double getTypeToTypeWeight(int *, int *);
+	double getTypeToTypeWeight_all1(int *t1, int *t2);
+	double getTypeToTypeWeight_weighted(int *t1, int *t2);
 	void sg_calc();
 
 	void sg_geometric();
 	void sg_geometric(double *);
+	void sg_big_geometric();
 	void sg_shrink_geometric(double *);
 	void sg_mass_geometric();
 	void sg_knn();
